# Theorem-like counters, separately for each type of theorem

Format 104
Counter theorem
	GuiName Theorem
	LaTeXName thm
	PrettyFormat "Theorem \arabic{theorem}"
End
Counter corollary
	GuiName Corollary
	LaTeXName cor
	PrettyFormat "Corollary \arabic{theorem}"
End
Counter lemma
	GuiName Lemma
	LaTeXName lem
	PrettyFormat "Lemma \arabic{theorem}"
End
Counter proposition
	GuiName Proposition
	LaTeXName prop
	PrettyFormat "Proposition \arabic{theorem}"
End
Counter conjecture
	GuiName Conjecture
	PrettyFormat "Conjecture \arabic{theorem}"
End
Counter fact
	GuiName Fact
	PrettyFormat "Fact \arabic{theorem}"
End
Counter definition
	GuiName Definition
	LaTeXName defn
	PrettyFormat "Definition \arabic{theorem}"
End
Counter example
	GuiName Example
	PrettyFormat "Example \arabic{theorem}"
End
Counter problem
	GuiName Problem
	PrettyFormat "Problem \arabic{theorem}"
End
Counter exercise
	GuiName Exercise
	LaTeXName xca
	PrettyFormat "Exercise \arabic{theorem}"
End
Counter solution
	GuiName Solution
	LaTeXName sol
	PrettyFormat "Solution \arabic{theorem}"
End
Counter remark
	GuiName Remark
	LaTeXName rem
	PrettyFormat "Remark \arabic{theorem}"
End
Counter claim
	GuiName Claim
	PrettyFormat "Claim \arabic{theorem}"
End
